library("kohonen")
data("wines")
wines.sc <- scale(wines)

set.seed(7)
wine.som <- som(data = wines.sc, grid = somgrid(5, 4, "hexagonal"))

pdf(file = "winesom.pdf", width = 5, height = 4)
plot(wine.som, main = "Wine data")
dev.off()

####
data("nir")
attach(nir)
set.seed(13)
nir.xyf <- xyf(data = spectra,
               Y = composition[,2],
               xweight = 0.5,
               grid = somgrid(6, 6, "hexagonal"))
pdf(file = "nirxyf.pdf", width = 5, height = 5)
plot(nir.xyf, type = "counts", main = "NIR data: counts")
dev.off()
pdf(file = "nirxyfsimi.pdf", width = 5, height = 5)
plot(nir.xyf, type = "quality", main = "NIR data: mapping quality")
dev.off()

####
set.seed(13)
nir.xyf2 <- xyf(data = spectra,
                Y = classvec2classmat(temperature),
                xweight = .2, grid = somgrid(6, 6, "hexagonal"))

####
water.predict <- predict(nir.xyf)$unit.prediction
temp.xyf <- predict(nir.xyf2)$unit.prediction
temp.predict <- as.numeric(classmat2classvec(temp.xyf))

pdf(file = "NIRpredictions.pdf", width = 10, height = 5.5)
par(mfrow = c(1,2))
plot(nir.xyf, type = "property", property = water.predict,
     main = "Prediction of water content", keepMargins = TRUE)
scatter <- matrix(rnorm(length(temperature)*2, sd = .1), ncol = 2)
radii <- (temperature - 20)/250
symbols(nir.xyf$grid$pts[nir.xyf$unit.classif,] + scatter,
        circles = radii, inches = FALSE, add = TRUE)

plot(nir.xyf2, type = "property", property = temp.predict,
     palette.name = rainbow, main = "Prediction of temperatures")
scatter <- matrix(rnorm(nrow(composition)*2, sd = .1), ncol = 2)
radii <- 0.05 + 0.4 * composition[,2]
symbols(nir.xyf2$grid$pts[nir.xyf2$unit.classif,] + scatter,
        circles = radii, inches = FALSE, add = TRUE)
dev.off()

#### 
pdf(file = "nircodes.pdf", width = 10, height = 5.5)
par(mfrow = c(1,2))
plot(nir.xyf2, "codes")
dev.off()

####
data("yeast")
set.seed(7)
yeast.supersom <- supersom(yeast, somgrid(8, 8, "hexagonal"),
                           whatmap = 3:6)
classes <- levels(yeast$class)
colors <- c("yellow", "green", "blue", "red", "orange")

pdf(file = "Separateclasses.pdf", width = 7, height = 10)
par(mfrow = c(3,2))
plot(yeast.supersom, type = "mapping",
     pch = 1, main = "All", keepMargins = TRUE)
for (i in seq(along = classes)) {
  X.class <- lapply(yeast,
                    function(x) subset(x, yeast$class == classes[i]))

  X.map <- map(yeast.supersom, X.class)
  plot(yeast.supersom, type = "mapping", classif = X.map,
       col = colors[i], pch = 1, main = classes[i], keepMargins = TRUE,
       bgcol = gray(0.85))
}
dev.off()


####
pdf(file = "training.pdf", width=10, height=3.5)
par(mfrow = c(1,3))
plot(wine.som, "changes", main = "Wine data: SOM")
plot(nir.xyf, "changes", main = "NIR data: XYF")
plot(yeast.supersom, "changes", main = "Yeast data: SUPERSOM")
dev.off()
